%% Minimal Realizations
% Various Matlab functions are demonstrated on the third-order
% system below. These highlight the distinction related to 
% minimal and non-minimal realizations

%% Define System
G = tf([3042 10140 3042],[1 13 199 507]);

%% Compute Poles / Zeros
zero(G) 

pole(G) 


%% Compute minimal realization
Gmin = minreal(G)

% G and Gmin have same step responses
t = linspace(0,2,100);
[y,t]=step(G,t);
[ymin,tmin]=step(G,t);

figure(1);
plot(t,y,'b',tmin,ymin,'r:');
grid on;
xlabel('Time (sec)');
ylabel('Output, y');
legend('Non-Minimal','Minimal','Location','Best')
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'MinReal')
end

