%% Step Response: First-order systems
%   dy/dt + a0*y = b0*u


%% Stable Response
a1 = 1;
a0 = [4 2 1 0.5];
b0 = a0;
s = -a0/a1;
ybar = b0./a0;

% Plot step response for each root
co = get(groot,'defaultAxesColorOrder');

figure(1);
clf;
for i=1:numel(s);
    if s(i)==0
        t=linspace(0,1.4,100);
    else
        t=linspace(0,3,100);
    end
    
    useExactSol = true; % Set to false for numerical solution
    
    if useExactSol
        % Exact Solution
        if s(i)==0
            y = (b0(i)/a1)*t;
        else
            y = ybar(i)*(1-exp(s(i)*t));
        end
    else
        % Numerical Solution
        G = tf(b0(i),[1 a0(i)]);
        [y,t]=step(G,t);        
    end
    plot(t,y,'Color',co(i,:));
    hold on;
end
ylim([0 2]);
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.57 0.7 0.3 0.2])
for i=1:numel(s)
    plot(s(i),0,'x','Color',co(i,:),'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
xlim([-4.5 0.25]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'FOStepStable')
end

%% Stable and Unstable Responses
a1 = 1;
a0 = [1 0 -0.5];
b0 = [1 1 1];
s = -a0/a1;
ybar = b0./a0;

% Plot step response for each root
figure(2);
clf;
for i=1:numel(s);
    if s(i)==0
        t=linspace(0,1.4,100);
    else
        t=linspace(0,3,100);
    end
    
    useExactSol = true; % Set to false for numerical solution
    
    if useExactSol
        % Exact Solution
        if s(i)==0
            y = (b0(i)/a1)*t;
        else
            y = ybar(i)*(1-exp(s(i)*t));
        end
    else
        % Numerical Solution
        G = tf(b0(i),[1 a0(i)]);
        [y,t]=step(G,t);        
    end
    plot(t,y,'Color',co(i,:));
    hold on;
end
ylim([0 2]);
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.62 0.72 0.3 0.2])
for i=1:numel(s)
    plot(s(i),0,'x','Color',co(i,:),'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
xlim([-1.5 1]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(2,'FOStepUnstable')
end
