%% Second Order Underdamped Step Response

%% Varying Real Part
% This plot holds im fixed and varies re

% Pick values of the real and imaginary parts of the root 
re = -0.25:-0.25:-1;    % Real part of root, rad/sec
im =  2;                % Imaginary part of root, rad/sec
wd = im;                % Damped natural frequency, rad/sec

% Compute values of zeta and wn corresponding to these roots
% Poles are at r = -zeta*wn +/- j*wd where wd = wn*sqrt(1-zeta^2)
zeta = 1./sqrt( 1+ wd^2./re.^2);  % Damping Ratio, unitless
wn = -re./zeta;                  % Natural Frequency, rad/sec

Gs = tf([]);
for i=1:numel(zeta)
    Gs(i,1) = tf(wn(i)^2,[1 2*zeta(i)*wn(i) wn(i)^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,10,100);

figure(1);
clf;
for i=1:numel(zeta)
    [y,t]=step(Gs(i),t);
    if i==1
        % Remove part of curve so roots/complex plane is fully visible
        y( t>5.9 & t<6.7 ) = NaN;
    end
    plot(t,y,'Color',co(i,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) 0 1.7]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.59 0.28 0.35 0.27])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    if abs(s(1)-s(2))<1e-5
        % Shift repeated poles slightly so they appear as double root
        plot([1.04; 0.96].*real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    else
        plot(real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    end
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
%set(gca,'XTick',[-10 -6 -3 -1 0],'YTick',[-5 -3 0 3 5])
axis([-1.2 0.1 -0.5 2.5]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'UnderdampedReal')
end


%% Varying Imaginary Part
% This plot holds re fixed and varies im

% Pick values of the real and imaginary parts of the root 
re = -1;            % Real part of root, rad/sec
im = 1:1:4;     % Imaginary part of root, rad/sec
wd = im;            % Damped natural frequency, rad/sec

% Compute values of zeta and wn corresponding to these roots
% Poles are at r = -zeta*wn +/- j*wd where wd = wn*sqrt(1-zeta^2)
zeta = 1./sqrt( 1+ wd.^2./re^2);  % Damping Ratio, unitless
wn = -re./zeta;                  % Natural Frequency, rad/sec

Gs = tf([]);
for i=1:numel(wn)
    Gs(i,1) = tf(wn(i)^2,[1 2*zeta(i)*wn(i) wn(i)^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,5,100);

figure(2);
clf;
for i=1:numel(wn)
    [y,t]=step(Gs(i),t);
    plot(t,y,'Color',co(i,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) 0 1.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.59 0.28 0.37 0.32])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    if abs(s(1)-s(2))<1e-5
        % Shift repeated poles slightly so they appear as double root
        plot([1.04; 0.96].*real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    else
        plot(real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    end
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
set(gca,'XTick',[-2:0.5:0],'YTick',[-5 -3 0 3 5])
axis([-2 0.1 -0.5 5]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');


if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(2,'UnderdampedImag')
end
