%% Effect of LHP and RHP (Real) Zeros

%% LHP Zeros

% Pick values of zeta, wn, and zero
zeta = 0.5;         % Damping Ratio, unitless
wn = 2;             % Natural Frequency, rad/sec
z = [-5 -2 -1 -0.5];

G0 = tf(wn^2,[1 2*zeta*wn wn^2]);
for i=1:numel(z)
    G(i,1) = tf(wn^2*[1/-z(i) 1],[1 2*zeta*wn wn^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,6,100);

figure(1);
clf;
for i=0:size(G,1)
    if i==0
        [y,t]=step(G0,t);
    else        
        [y,t]=step(G(i),t);
    end
    plot(t,y,'Color',co(i+1,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) 0 2.75]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.42 0.6 0.55 0.35])
for i=0:size(G,1)    
    if i==0
        Gi = G0;
    else
        Gi = G(i);
    end
    s = pole(Gi);
    z = zero(Gi);
    plot(real(s),imag(s),'kx',...
        'MarkerSize',12);
    plot(real(z),imag(z),'o','Color',co(i+1,:),...
        'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
%set(gca,'XTick',[-10 -6 -3 -1 0],'YTick',[-5 -3 0 3 5])
axis([-6 0.1 -0.5 2.5]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'LHPZero')
end


%% RHP Zeros

% Pick values of zeta, wn, and zero
zeta = 0.5;         % Damping Ratio, unitless
wn = 2;             % Natural Frequency, rad/sec
z = -[-5 -2 -1 -0.5];

G0 = tf(wn^2,[1 2*zeta*wn wn^2]);
for i=1:numel(z)
    G(i,1) = tf(wn^2*[1/-z(i) 1],[1 2*zeta*wn wn^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,6,100);

figure(2);
clf;
for i=0:size(G,1)
    if i==0
        [y,t]=step(G0,t);
    else        
        [y,t]=step(G(i),t);
    end
    plot(t,y,'Color',co(i+1,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) -2 1.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.4 0.3 0.55 0.35])
for i=0:size(G,1)    
    if i==0
        Gi = G0;
    else
        Gi = G(i);
    end
    s = pole(Gi);
    z = zero(Gi);
    plot(real(s),imag(s),'kx',...
        'MarkerSize',12);
    plot(real(z),imag(z),'o','Color',co(i+1,:),...
        'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
%set(gca,'XTick',[-10 -6 -3 -1 0],'YTick',[-5 -3 0 3 5])
axis([-2 6 -0.5 2.5]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(2,'RHPZero')
end


